[![Build Status](https://travis-ci.org/polyaxon/polyaxon-schemas.svg?branch=master)](https://travis-ci.org/polyaxon/polyaxon-schemas)
[![PyPI version](https://badge.fury.io/py/polyaxon-schemas.svg)](https://badge.fury.io/py/polyaxon-schemas)
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](LICENSE)
[![Gitter](https://img.shields.io/gitter/room/nwjs/nw.js.svg)](https://gitter.im/polyaxon/polyaxon)

# Polyaxon-schemas

Schema definitions and validation for Polyaxon.


# License

[![FOSSA Status](https://app.fossa.io/api/projects/git%2Bgithub.com%2Fpolyaxon%2Fpolyaxon-schemas.svg?type=large)](https://app.fossa.io/projects/git%2Bgithub.com%2Fpolyaxon%2Fpolyaxon-schemas?ref=badge_large)
